import { Body, Controller, Get, HttpException, HttpStatus, Post, Query, Req, UseGuards } from '@nestjs/common';
import { AuthenticationService } from './authentication.service';
import RegisterDto from './dto/register.dto';
import { JwtGuard } from './guard/jwt.guard';
import { LoginGuard } from './guard/login.guard';
import RequestWithSession from './interface/requestWithSession.interface';

@Controller('authentication')
export class AuthenticationController {
	constructor(private readonly authenticationService: AuthenticationService) {}

  @UseGuards(LoginGuard)
	@Post('login')
  async login(@Req() { session }: RequestWithSession) {
    const idToken = session.getIdToken();
    const refreshToken = session.getRefreshToken();
    //send when usage found
    //const accessToken = session.getAccessToken();
    return {
      idToken: idToken.getJwtToken(),
      idTokenPayload: idToken.decodePayload(),
      refreshToken: refreshToken.getToken(),
    };
  }

  @Post('register')
  async register(@Body() registrationData: RegisterDto) {
    try {
      await this.authenticationService.register(registrationData);
    } catch (err) {
      throw new HttpException({
        status: HttpStatus.BAD_REQUEST,
        error: err.message
      }, HttpStatus.BAD_REQUEST);
    }
    return 'account created';
  }

  @Get('confirm-email')
  async confirm(@Query('code') code: string, @Query('email') email: string) {
    try {
      await this.authenticationService.confirm(email, code);
    } catch (err) {
      throw new HttpException({
        status: HttpStatus.UNAUTHORIZED,
        error: err.message
      }, HttpStatus.UNAUTHORIZED);
    }
    return 'email confirmed';
  }

  //refresh
  //password-reset
  //email-change
  //resend-code

  //create user table with dynamoose
  //index on user name
  @UseGuards(JwtGuard)
  @Get()
  async test(@Req() { session }: RequestWithSession) {
    return session
  }
}
