import { HttpException, HttpStatus, Injectable } from "@nestjs/common";
import { Strategy } from 'passport-local';
import { PassportStrategy } from "@nestjs/passport";
import { CognitoUserSession } from "amazon-cognito-identity-js";
import { AuthenticationService } from "../authentication.service";

@Injectable()
export class LoginStrategy extends PassportStrategy(Strategy) {
  constructor(private authenticationService: AuthenticationService) {
    super({
      usernameField: 'email'
    });
  }
  async validate(email: string, password: string): Promise<CognitoUserSession> {
    try {
      return this.authenticationService.login(email, password);
    } catch (err) {
      throw new HttpException({
      status: HttpStatus.UNAUTHORIZED,
      error: err.message
      }, HttpStatus.UNAUTHORIZED);
    }
  }
}